@@ -107,9 +107,9 @@ class color_print():
 
     def lenString(self, string):
         """Получаем длинну строки"""
-        stringUnicode = _u(string)
-        lenString = len(stringUnicode)
-        return lenString
+        # stringUnicode = _u(string)
+        # lenString = len(stringUnicode)
+        return len(string)
 
     def defaultPrint(self, string):
         try:
