@@ -95,8 +95,8 @@ class backgrounds(TemplateFormat):
         if self.convert != "gfxboot" and (
             (width == self.source_width and height == self.source_height) and
                 (source.rpartition('.')[2] == target.rpartition('.')[2])):
-            with writeFile(target) as sf:
-                sf.write(readFile(source))
+            with writeFile(target, binary=True) as sf:
+                sf.write(readFile(source, binary=True))
             return True
         if self.chroot_cmd:
             source = self.trim_chroot_path(source)
