@@ -15,13 +15,13 @@
 #  limitations under the License.
 import os
 import re
-from calculate.lib.datavars import Variable, ReadonlyVariable, DataVarsError
-from calculate.lib.utils.files import process, FilesError, readFile
-from calculate.lib.utils.common import (
+from ..datavars import Variable, ReadonlyVariable, DataVarsError
+from ..utils.files import process, FilesError, readFile
+from ..utils.common import (
     getValueFromCmdLine, getVideoFromXorgLog, getVideoFromXorgConf,
     getVideoFromCmdLine, getCompositeFromXorgconf, getTupleVersion,
     getVideoFromModules, getVideoFromVendor, getInstalledVideo, CmdlineParams)
-from calculate.lib.utils.portage import isPkgInstalled
+from ..utils.portage import isPkgInstalled
 from math import sqrt
 
 
@@ -71,8 +71,8 @@ class VariableOsX11Resolution(Variable):
                     reXorgLogParser = re.compile(re_pat, re.S)
                     resXorgLogParser = reXorgLogParser.search(logdata)
                     if resXorgLogParser:
-                        return "%sx%s" % filter(lambda x: x,
-                                                resXorgLogParser.groups())[:2]
+                        tmp = [x for x in resXorgLogParser.groups() if x]
+                        return "%sx%s" % tuple(tmp[:2])
 
             # get resolution from xorg.conf
             xorgconf = "/etc/X11/xorg.conf"
@@ -80,12 +80,10 @@ class VariableOsX11Resolution(Variable):
                                           re.S)
             reModes = re.compile('Modes\s+"(\d+x\d+)')
             if os.access(xorgconf, os.R_OK):
-                sectionsScreen = filter(lambda x: "Modes" in x,
-                                         reScreenSections.findall(
-                                             readFile('/etc/X11/xorg.conf')))
-                modes = map(lambda x: x.groups()[0],
-                            filter(lambda x: x,
-                                   map(reModes.search, sectionsScreen)))
+                sectionsScreen = [x for x 
+                        in reScreenSections.findall(readFile('/etc/X11/xorg.conf')) 
+                        if "Modes" in x]
+                modes = [x.groups()[0] for x in map(reModes.search, sectionsScreen) if x]
                 if modes:
                     return max(modes, key=lambda x: int(x.partition('x')[0]))
 
@@ -207,9 +205,12 @@ class VariableClResolutions(Variable):
     def get(self):
         if self.Get('cl_chroot_status') == 'off':
             try:
-                values = filter(None, list({
+                # values = list(filter(None, list({
+                #     self.Get('install.os_install_fb_resolution'),
+                #     self.Get('install.os_install_x11_resolution')})))
+                values = [x for x in list({
                     self.Get('install.os_install_fb_resolution'),
-                    self.Get('install.os_install_x11_resolution')}))
+                    self.Get('install.os_install_x11_resolution')}) if x]
                 if values:
                     return values
             except DataVarsError:
